/*
Copyright (c) 2019 the Octant contributors. All Rights Reserved.
SPDX-License-Identifier: Apache-2.0
*/

package objectstatus

import (
	"context"

	"github.com/vmware-tanzu/octant/internal/link"

	"github.com/pkg/errors"
	corev1 "k8s.io/api/core/v1"
	"k8s.io/apimachinery/pkg/runtime"
	"k8s.io/client-go/kubernetes/scheme"

	"github.com/vmware-tanzu/octant/pkg/store"
	"github.com/vmware-tanzu/octant/pkg/view/component"
)

func replicationController(_ context.Context, object runtime.Object, _ store.Store, _ link.Interface) (ObjectStatus, error) {
	if object == nil {
		return ObjectStatus{}, errors.Errorf("replication controller is nil")
	}

	rc := &corev1.ReplicationController{}

	if err := scheme.Scheme.Convert(object, rc, 0); err != nil {
		return ObjectStatus{}, errors.Wrap(err, "convert object to replication controller")
	}

	status := rc.Status

	switch {
	case status.ReadyReplicas != status.Replicas:
		return ObjectStatus{
			NodeStatus: component.NodeStatusWarning,
			Details:    []component.Component{component.NewText("Replication Controller pods are not ready")},
		}, nil
	default:
		return ObjectStatus{
			NodeStatus: component.NodeStatusOK,
			Details:    []component.Component{component.NewText("Replication Controller is OK")},
		}, nil
	}
}
